==> climetlab-plugin-tools-0.0.2.tar.gz: climetlab-plugin-tools-0.0.2/climetlab_plugin_tools/templates/dataset/setup.py <==
#!/usr/bin/env python
# licence_header_climetlab_template


import io
import os

import setuptools


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return io.open(file_path, encoding="utf-8").read()


package_name = "climetlab_plugin_name_climetlab_template"  # noqa: E501

version = None
lines = read(f"{package_name}/version").split("\n")
if lines:
    version = lines[0]

assert version


extras_require = {}

setuptools.setup(
    name=package_name,
    version=version,
    description=(
        "A dataset plugin for climetlab for the dataset "
        "dataset-full-name-climetlab-template"  # noqa: E501
    ),
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="full_name_climetlab_template",
    author_email="email_climetlab_template",
    url="http://github.com/repo_url_climetlab_template",
    license="Apache License Version 2.0",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=["climetlab>=0.10.0"],
    extras_require=extras_require,
    zip_safe=True,
    entry_points={
        "climetlab.datasets": [
            # End-users will use cml.load_dataset("dataset-full-name-climetlab-template", ...)
            # see the tests/ folder for a example.
            "dataset-full-name-climetlab-template= climetlab_plugin_name_climetlab_template.dataset_name_climetlab_template:DatasetNameClimetlabTemplate",  # noqa: E501
            # Other datasets can be included here
            # "plugin-name-climetlab-template-dataset-2= climetlab_plugin_name_climetlab_template.dataset_name_climetlab_template2:DatasetNameClimetlabTemplate2",  # noqa: E501
        ]
        # source plugins would be here
        # "climetlab.sources": []
    },
    keywords="meteorology",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
    ],
)

==> climetlab-plugin-tools-0.0.4.tar.gz: climetlab-plugin-tools-0.0.4/climetlab_plugin_tools/templates/dataset/setup.py <==
#!/usr/bin/env python
# licence_header_climetlab_template


import io
import os

import setuptools


def read(fname):
    file_path = os.path.join(os.path.dirname(__file__), fname)
    return io.open(file_path, encoding="utf-8").read()


package_name = "climetlab_plugin_name_climetlab_template"  # noqa: E501

version = None
lines = read(f"{package_name}/version").split("\n")
if lines:
    version = lines[0]

assert version


extras_require = {}

setuptools.setup(
    name=package_name,
    version=version,
    description=(
        "A dataset plugin for climetlab for the dataset dataset-full-name-climetlab-template"  # noqa: E501
    ),
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    author="full_name_climetlab_template",
    author_email="email_climetlab_template",
    url="http://github.com/repo_url_climetlab_template",
    license="Apache License Version 2.0",
    packages=setuptools.find_packages(),
    include_package_data=True,
    install_requires=["climetlab>=0.10.0"],
    extras_require=extras_require,
    zip_safe=True,
    entry_points={
        "climetlab.datasets": [
            # End-users will use cml.load_dataset("dataset-full-name-climetlab-template", ...)
            # see the tests/ folder for a example.
            "dataset-full-name-climetlab-template= climetlab_plugin_name_climetlab_template.dataset_name_climetlab_template:DatasetNameClimetlabTemplate",  # noqa: E501
            # Other datasets can be included here
            # "plugin-name-climetlab-template-dataset-2= climetlab_plugin_name_climetlab_template.dataset_name_climetlab_template2:DatasetNameClimetlabTemplate2",  # noqa: E501
        ]
        # source plugins would be here
        # "climetlab.sources": []
    },
    keywords="meteorology",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: Implementation :: CPython",
        "Programming Language :: Python :: Implementation :: PyPy",
        "Operating System :: OS Independent",
    ],
)
